bayespy.inference.vmp.nodes.beta.BetaDistribution.compute_logpdf
================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.beta

.. automethod:: BetaDistribution.compute_logpdf